@@ -7,8 +7,7 @@ pub mod chain;
 
 #[cfg(test)]
 mod tests {
-    use super::chain::*;
-    use crate::blocks::chain::init_blockchain;
+    use crate::blocks::chain::*;
 
     #[test]
     fn test_new_block() -> std::io::Result<()> {
@@ -39,10 +38,8 @@ mod tests {
     }
 
     #[test]
-    fn test_blockchain() -> std::io::Result<()> {
+    fn test_blockchain() {
         let _bc: Blockchain = init_blockchain("test_blockchaindb").unwrap();
-
-        Ok(())
     }
 
     #[test]
